OutboxService

Struct OutboxService 

pub struct OutboxService<W, S, P>
where P: Debug + Clone + Serialize + Send + Sync,
{ /* private fields */ }

Implementations

Source

impl<W, P> OutboxService<W, NoIdempotency, P>
where W: OutboxWriter<P> + Send + Sync + 'static, P: Debug + Clone + Serialize + Send + Sync,

pub fn new(writer: Arc<W>, config: Arc<OutboxConfig<P>>) -> Self

Source

impl<W, S, P> OutboxService<W, S, P>
where W: OutboxWriter<P> + Send + Sync + 'static, S: IdempotencyStorageProvider + Send + Sync + 'static, P: Debug + Clone + Serialize + Send + Sync,

pub fn with_idempotency( writer: Arc<W>, config: Arc<OutboxConfig<P>>, idempotency_storage: Arc<S>, ) -> Self

pub async fn add_event<F>( &self, event_type: &str, payload: P, provided_token: Option<String>, get_event: F, ) -> Result<(), OutboxError>
where F: FnOnce() -> Option<Event<P>>, P: Debug + Clone + Serialize + Send + Sync,

Adds a new event to the outbox storage with idempotency checks.

If an idempotency provider is configured and a token is generated, it will first attempt to reserve the token to prevent duplicate processing.

Errors

Returns OutboxError::DuplicateEvent if the event token has already been used. Returns OutboxError if the idempotency storage fails or the database insert operation fails.

Panics

Panics if the idempotency strategy is set to Custom, but get_event returns None.